AUC_per_reader_nest: MRMC analysis in nested data problem
Description
This function takes nested data as a data frame and runs a multi-reader multi-case analysis for single reader in nested
data problem based on modified U-statistics as described in the following paper:
Usage
AUC_per_reader_nest(data)
Value
This function returns a list containing three dataframes.
Here is a quick summary:
AUC_per_reader [data.frame] this data frame contains the AUC estimates for each reader under different modalities (Mod1 denotes modality 1 and Mod2 denotes modality 2).
AUC_Var_per_reader [data.frame] this data frame contains the AUC variance estimates for each reader under different modalities.
numROI [data.frame] this data frame contains the number of positive and negative ROIs in each case.
Arguments
data
The nested data for analysis. This dataset should have specified columns:
"patient","reader1","reader2","reader3","reader4","reader5","truth","mod","region".