Configuration function
simu_config(
I = 100,
k = 10,
R = 2,
correlation_t = 0,
potential_correlation_s = rep(0.5, 4),
AUC_all = rep(0.7, 2),
sameclustersize = TRUE,
rho = 0.5,
fix_design = FALSE,
stream = 20220210,
initial_seed = 20220222
)A list of above parameters
The number of patients.
The number of ROIs in each patient.
The number of readers.
The correlation for simulating truth label.
The correlation for simulating reading scores.
The theoretical AUC values.
The binary variable to decide whether we have same number of ROIs in each patient.
The scale parameter that influence the covariance matrix in multivariate normal distribution.
Binary variable to decide whether fix the truth label in simulation.
The integer control the random number generator.
The integer control the random seed for truth label generation.